# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FILE_TOOL_METADATA = Metadata(
    id="a338b51bc00f0441446c6ca843266cef70008a68.boutiques",
    name="file_tool",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FileToolOutputs(typing.NamedTuple):
    """
    Output object returned when calling `file_tool(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    modified_file: OutputPathType | None
    """The modified output file"""


def file_tool(
    infiles: list[InputPathType],
    help_: bool = False,
    version: bool = False,
    hist: bool = False,
    debug: float | None = None,
    ge_all: bool = False,
    ge_header: bool = False,
    ge_extras: bool = False,
    ge_uv17: bool = False,
    ge_run: bool = False,
    ge_off: bool = False,
    ge4_all: bool = False,
    ge4_image: bool = False,
    ge4_series: bool = False,
    ge4_study: bool = False,
    def_ana_hdr: bool = False,
    diff_ana_hdrs: bool = False,
    disp_ana_hdr: bool = False,
    hex_: bool = False,
    mod_ana_hdr: bool = False,
    mod_field: str | None = None,
    prefix: str | None = None,
    overwrite: bool = False,
    show_bad_all: bool = False,
    show_bad_backslash: bool = False,
    show_bad_char: bool = False,
    show_file_type: bool = False,
    fix_rich_quotes: str | None = None,
    test: bool = False,
    length: float | None = None,
    mod_data: str | None = None,
    mod_type: str | None = None,
    offset: float | None = None,
    quiet: bool = False,
    disp_hex: bool = False,
    disp_hex1: bool = False,
    disp_hex2: bool = False,
    disp_hex4: bool = False,
    disp_int2: bool = False,
    disp_int4: bool = False,
    disp_real4: bool = False,
    swap_bytes: bool = False,
    runner: Runner | None = None,
) -> FileToolOutputs:
    """
    Program to display or modify sections of a file.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infiles: Specify input files to display or modify.
        help_: Show help information.
        version: Show version information.
        hist: Show the program's modification history.
        debug: Print extra info along the way, default is 0, max is 2.
        ge_all: Display GE header and extras info.
        ge_header: Display GE header info.
        ge_extras: Display extra GE image info.
        ge_uv17: Display the value of uv17 (the run #).
        ge_run: Display the value of uv17 (the run #).
        ge_off: Display file offsets for various fields.
        ge4_all: Display GEMS 4.x series and image headers.
        ge4_image: Display GEMS 4.x image header.
        ge4_series: Display GEMS 4.x series header.
        ge4_study: Display GEMS 4.x study header.
        def_ana_hdr: Display the definition of an ANALYZE header.
        diff_ana_hdrs: Display field differences between 2 headers.
        disp_ana_hdr: Display ANALYZE headers.
        hex_: Display field values in hexadecimal.
        mod_ana_hdr: Modify ANALYZE headers.
        mod_field: Specify a field and value(s) to modify.
        prefix: Specify an output filename.
        overwrite: Specify to overwrite the input file(s).
        show_bad_all: Show lines with whitespace after '\\'.
        show_bad_backslash: Show lines with whitespace after '\\'.
        show_bad_char: Show any non-printable characters.
        show_file_type: Print file type of UNIX, Mac or DOS.
        fix_rich_quotes: Replace rich-text quotes with ASCII.
        test: Short for -show_bad_all. Check script files for known issues.
        length: Specify the number of bytes to print/modify.
        mod_data: Specify a string to modify the data to.
        mod_type: Specify the data type to write to the file.
        offset: Specify the offset into each file.
        quiet: Do not output header information.
        disp_hex: Display bytes in hex.
        disp_hex1: Display bytes in hex.
        disp_hex2: Display 2-byte integers in hex.
        disp_hex4: Display 4-byte integers in hex.
        disp_int2: Display 2-byte integers.
        disp_int4: Display 4-byte integers.
        disp_real4: Display 4-byte real numbers.
        swap_bytes: Use byte-swapping on numbers.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FileToolOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FILE_TOOL_METADATA)
    cargs = []
    cargs.append("file_tool")
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    if hist:
        cargs.append("-hist")
    if debug is not None:
        cargs.extend([
            "-debug",
            str(debug)
        ])
    cargs.extend([
        "-infiles",
        *[execution.input_file(f) for f in infiles]
    ])
    if ge_all:
        cargs.append("-ge_all")
    if ge_header:
        cargs.append("-ge_header")
    if ge_extras:
        cargs.append("-ge_extras")
    if ge_uv17:
        cargs.append("-ge_uv17")
    if ge_run:
        cargs.append("-ge_run")
    if ge_off:
        cargs.append("-ge_off")
    if ge4_all:
        cargs.append("-ge4_all")
    if ge4_image:
        cargs.append("-ge4_image")
    if ge4_series:
        cargs.append("-ge4_series")
    if ge4_study:
        cargs.append("-ge4_study")
    if def_ana_hdr:
        cargs.append("-def_ana_hdr")
    if diff_ana_hdrs:
        cargs.append("-diff_ana_hdrs")
    if disp_ana_hdr:
        cargs.append("-disp_ana_hdr")
    if hex_:
        cargs.append("-hex")
    if mod_ana_hdr:
        cargs.append("-mod_ana_hdr")
    if mod_field is not None:
        cargs.extend([
            "-mod_field",
            mod_field
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if overwrite:
        cargs.append("-overwrite")
    if show_bad_all:
        cargs.append("-show_bad_all")
    if show_bad_backslash:
        cargs.append("-show_bad_backslash")
    if show_bad_char:
        cargs.append("-show_bad_char")
    if show_file_type:
        cargs.append("-show_file_type")
    if fix_rich_quotes is not None:
        cargs.extend([
            "-fix_rich_quotes",
            fix_rich_quotes
        ])
    if test:
        cargs.append("-test")
    if length is not None:
        cargs.extend([
            "-length",
            str(length)
        ])
    if mod_data is not None:
        cargs.extend([
            "-mod_data",
            mod_data
        ])
    if mod_type is not None:
        cargs.extend([
            "-mod_type",
            mod_type
        ])
    if offset is not None:
        cargs.extend([
            "-offset",
            str(offset)
        ])
    if quiet:
        cargs.append("-quiet")
    if disp_hex:
        cargs.append("-disp_hex")
    if disp_hex1:
        cargs.append("-disp_hex1")
    if disp_hex2:
        cargs.append("-disp_hex2")
    if disp_hex4:
        cargs.append("-disp_hex4")
    if disp_int2:
        cargs.append("-disp_int2")
    if disp_int4:
        cargs.append("-disp_int4")
    if disp_real4:
        cargs.append("-disp_real4")
    if swap_bytes:
        cargs.append("-swap_bytes")
    ret = FileToolOutputs(
        root=execution.output_file("."),
        modified_file=execution.output_file(prefix) if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FILE_TOOL_METADATA",
    "FileToolOutputs",
    "file_tool",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DNEWID_METADATA = Metadata(
    id="acbbcc60d614fe39bf285beddcf6984090e82ecf.boutiques",
    name="3dnewid",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dnewidOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dnewid(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3dnewid(
    datasets: list[InputPathType],
    fun: float | None = None,
    fun11: bool = False,
    int_: bool = False,
    hash_: str | None = None,
    md5: str | None = None,
    runner: Runner | None = None,
) -> V3dnewidOutputs:
    """
    Assigns a new ID code to a dataset, ensuring internal ID codes remain unique.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        datasets: Input datasets to assign new ID codes.
        fun: Generate n randomly generated ID codes. If n is not present, 1 ID\
            code is printed.
        fun11: Generate an 11 character ID code for use in scripting.
        int_: Generate a random positive integer between 1 million and 1\
            billion.
        hash_: Generate a unique hash code of the provided string. The same\
            string produces the same hash code.
        md5: Generate the MD5 hash of the provided string. Output should be the\
            same as the -hash output without the prefix and without the + and /\
            char substitutions.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dnewidOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DNEWID_METADATA)
    cargs = []
    cargs.append("3dnewid")
    cargs.extend([execution.input_file(f) for f in datasets])
    if fun is not None:
        cargs.extend([
            "-fun",
            str(fun)
        ])
    if fun11:
        cargs.append("-fun11")
    if int_:
        cargs.append("-int")
    if hash_ is not None:
        cargs.extend([
            "-hash",
            hash_
        ])
    if md5 is not None:
        cargs.extend([
            "-MD5",
            md5
        ])
    ret = V3dnewidOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dnewidOutputs",
    "V_3DNEWID_METADATA",
    "v_3dnewid",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SEGSTATS_METADATA = Metadata(
    id="de1b9dfa3f1dac83d5a96b745b8f327109cb07d4.boutiques",
    name="mri_segstats",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSegstatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_segstats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    summary_output_file: OutputPathType
    """Output file for summary statistics."""
    avg_waveform_output: OutputPathType | None
    """Average waveform output text file."""
    sum_waveform_output: OutputPathType | None
    """Sum waveform output text file."""
    avg_waveform_vol_output: OutputPathType | None
    """Average waveform volume output file."""
    spatial_frame_avg_output: OutputPathType | None
    """Spatial frame average output file."""
    ctab_output_file: OutputPathType | None
    """Output color table with the reported segmentations."""


def mri_segstats(
    segvol: InputPathType,
    output_file: str,
    annot_subject: str | None = None,
    annot_hemisphere: str | None = None,
    annot_parcellation: str | None = None,
    slabel_subject: str | None = None,
    slabel_hemisphere: str | None = None,
    slabel_label: InputPathType | None = None,
    partial_vol_comp: InputPathType | None = None,
    input_volume: InputPathType | None = None,
    seg_erode: float | None = None,
    frame: float | None = None,
    robust: float | None = None,
    square_input: bool = False,
    sqrt_input: bool = False,
    multiply_input: float | None = None,
    divide_input: float | None = None,
    snr_column: bool = False,
    absolute_value: bool = False,
    accumulate_mean: bool = False,
    color_table: InputPathType | None = None,
    default_color_table: bool = False,
    gca_color_table: InputPathType | None = None,
    ids: str | None = None,
    exclude_ids: str | None = None,
    exclude_gm_wm: bool = False,
    surf_wm_vol: bool = False,
    surf_ctx_vol: bool = False,
    no_global_stats: bool = False,
    empty_segments: bool = False,
    ctab_output: str | None = None,
    mask_volume: InputPathType | None = None,
    mask_threshold: float | None = None,
    mask_sign: str | None = None,
    mask_frame: float | None = None,
    invert_mask: bool = False,
    mask_erode: float | None = None,
    brain_vol_seg: bool = False,
    brain_mask_vol: InputPathType | None = None,
    subcortical_gray: bool = False,
    total_gray: bool = False,
    intracranial_volume: bool = False,
    intracranial_volume_only: bool = False,
    old_intracranial_volume_only: bool = False,
    talairach_transform: InputPathType | None = None,
    xfm_to_etiv: str | None = None,
    euler_hole_count: bool = False,
    avg_waveform: str | None = None,
    sum_waveform: str | None = None,
    avg_waveform_vol: str | None = None,
    remove_avgwf_mean: bool = False,
    spatial_frame_avg: str | None = None,
    voxel_crs: str | None = None,
    replace_ids: str | None = None,
    replace_ids_file: InputPathType | None = None,
    gtm_default_seg_merge: bool = False,
    gtm_default_seg_merge_choroid: bool = False,
    qa_stats_file: str | None = None,
    subjects_dir: str | None = None,
    random_seed: float | None = None,
    runner: Runner | None = None,
) -> MriSegstatsOutputs:
    """
    Calculates measures and stats derived from brain segmentation data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        segvol: Input segmentation volume. This volume's voxel values indicate\
            a segmentation or class.
        output_file: ASCII file in which summary statistics are saved.
        annot_subject: Create a segmentation from hemi.parc.annot. Subject is\
            the name of the subject.
        annot_hemisphere:.
        annot_parcellation:.
        slabel_subject: Create a segmentation from the given surface label. The\
            points in the label are given a value of 1; 0 for outside.
        slabel_hemisphere:.
        slabel_label:.
        partial_vol_comp: Use pvvol to compensate for partial voluming,\
            resulting in more accurate volumes.
        input_volume: Input volume from which to compute more statistics.
        seg_erode: Erode segmentation boundaries by Nerodes.
        frame: Report statistics of the input volume at the specified 0-based\
            frame number.
        robust: Compute stats after excluding a percentage of high and low\
            values.
        square_input: Compute the square of the input before computing stats.
        sqrt_input: Compute the square root of the input before computing\
            stats.
        multiply_input: Multiply input by value.
        divide_input: Divide input by value.
        snr_column: Save mean/std as extra column in output table.
        absolute_value: Compute absolute value of input before spatial average.
        accumulate_mean: Save mean*nvoxels instead of mean.
        color_table: FreeSurfer color table file to specify how each\
            segmentation index is mapped to a segmentation name and color.
        default_color_table: Use default color table from\
            FreeSurferColorLUT.txt.
        gca_color_table: Get color table from the given GCA file.
        ids: Specify numeric segmentation ids.
        exclude_ids: Exclude the given segmentation id(s) from report.
        exclude_gm_wm: Exclude cortical gray and white matter based on\
            predefined IDs.
        surf_wm_vol: Compute cortical matter volume based on the white surface\
            volume.
        surf_ctx_vol: Compute cortical volumes from surface.
        no_global_stats: Turns off computation of global stats.
        empty_segments: Report on segmentations listed in the color table even\
            if they are not found in the segmentation volume.
        ctab_output: Create an output color table with just the segmentations\
            reported.
        mask_volume: Exclude voxels that are not in the mask. Voxels to be\
            excluded are assigned a segid of 0.
        mask_threshold: Exclude voxels that are below thresh, above -thresh, or\
            between -thresh and +thresh.
        mask_sign: Specify sign for masking threshold. Choices are abs, pos,\
            and neg.
        mask_frame: Derive the mask volume from the specified 0-based frame.
        invert_mask: After applying all the masking criteria, invert the mask.
        mask_erode: Erode mask by specified number of iterations.
        brain_vol_seg: Get volume of brain as the sum of the volumes of the\
            segmentations that are in the brain.
        brain_mask_vol: Load brain mask and compute brain volume from non-zero\
            voxels.
        subcortical_gray: Compute volume of subcortical gray matter.
        total_gray: Compute volume of total gray matter.
        intracranial_volume: Compute intracranial volume from talairach.xfm.
        intracranial_volume_only: Compute intracranial volume from\
            talairach.xfm and exit.
        old_intracranial_volume_only: Compute intracranial volume from\
            talairach_with_skull.lta and exit.
        talairach_transform: Specify path to talairach.xfm file for eTIV.
        xfm_to_etiv: Convert xfm to eTIV and write to output file.
        euler_hole_count: Write out number of defect holes based on the Euler\
            number.
        avg_waveform: Compute the average waveform and save to text file.
        sum_waveform: Compute the sum waveform and save to text file.
        avg_waveform_vol: Compute average waveform and save to MRI volume.
        remove_avgwf_mean: Remove temporal mean from avgwf and avgwfvol.
        spatial_frame_avg: Save mean across space and frame.
        voxel_crs: Replace segmentation with all 0s except at specified voxel.
        replace_ids: Replace segmentation ID1 with ID2.
        replace_ids_file: Replace segmentations based on pairs in file.
        gtm_default_seg_merge: Replace segmentations based on GTM default.
        gtm_default_seg_merge_choroid: Replace segmentations based on GTM\
            default excluding choroid.
        qa_stats_file: Compute stats useful for quality control.
        subjects_dir: Set SUBJECTS_DIR environment variable.
        random_seed: Set random number generator seed value.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSegstatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SEGSTATS_METADATA)
    cargs = []
    cargs.append("mri_segstats")
    cargs.extend([
        "--seg",
        execution.input_file(segvol)
    ])
    if annot_subject is not None:
        cargs.extend([
            "--annot",
            annot_subject
        ])
    if annot_hemisphere is not None:
        cargs.append(annot_hemisphere)
    if annot_parcellation is not None:
        cargs.append(annot_parcellation)
    if slabel_subject is not None:
        cargs.extend([
            "--slabel",
            slabel_subject
        ])
    if slabel_hemisphere is not None:
        cargs.append(slabel_hemisphere)
    if slabel_label is not None:
        cargs.append(execution.input_file(slabel_label))
    cargs.extend([
        "--o",
        output_file
    ])
    if partial_vol_comp is not None:
        cargs.extend([
            "--pv",
            execution.input_file(partial_vol_comp)
        ])
    if input_volume is not None:
        cargs.extend([
            "--i",
            execution.input_file(input_volume)
        ])
    if seg_erode is not None:
        cargs.extend([
            "--seg-erode",
            str(seg_erode)
        ])
    if frame is not None:
        cargs.extend([
            "--frame",
            str(frame)
        ])
    if robust is not None:
        cargs.extend([
            "--robust",
            str(robust)
        ])
    if square_input:
        cargs.append("--sqr")
    if sqrt_input:
        cargs.append("--sqrt")
    if multiply_input is not None:
        cargs.extend([
            "--mul",
            str(multiply_input)
        ])
    if divide_input is not None:
        cargs.extend([
            "--div",
            str(divide_input)
        ])
    if snr_column:
        cargs.append("--snr")
    if absolute_value:
        cargs.append("--abs")
    if accumulate_mean:
        cargs.append("--accumulate")
    if color_table is not None:
        cargs.extend([
            "--ctab",
            execution.input_file(color_table)
        ])
    if default_color_table:
        cargs.append("--ctab-default")
    if gca_color_table is not None:
        cargs.extend([
            "--ctab-gca",
            execution.input_file(gca_color_table)
        ])
    if ids is not None:
        cargs.extend([
            "--id",
            ids
        ])
    if exclude_ids is not None:
        cargs.extend([
            "--excludeid",
            exclude_ids
        ])
    if exclude_gm_wm:
        cargs.append("--excl-ctxgmwm")
    if surf_wm_vol:
        cargs.append("--surf-wm-vol")
    if surf_ctx_vol:
        cargs.append("--surf-ctx-vol")
    if no_global_stats:
        cargs.append("--no-global-stats")
    if empty_segments:
        cargs.append("--empty")
    if ctab_output is not None:
        cargs.extend([
            "--ctab-out",
            ctab_output
        ])
    if mask_volume is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask_volume)
        ])
    if mask_threshold is not None:
        cargs.extend([
            "--maskthresh",
            str(mask_threshold)
        ])
    if mask_sign is not None:
        cargs.extend([
            "--masksign",
            mask_sign
        ])
    if mask_frame is not None:
        cargs.extend([
            "--maskframe",
            str(mask_frame)
        ])
    if invert_mask:
        cargs.append("--maskinvert")
    if mask_erode is not None:
        cargs.extend([
            "--maskerode",
            str(mask_erode)
        ])
    if brain_vol_seg:
        cargs.append("--brain-vol-from-seg")
    if brain_mask_vol is not None:
        cargs.extend([
            "--brainmask",
            execution.input_file(brain_mask_vol)
        ])
    if subcortical_gray:
        cargs.append("--subcortgray")
    if total_gray:
        cargs.append("--totalgray")
    if intracranial_volume:
        cargs.append("--etiv")
    if intracranial_volume_only:
        cargs.append("--etiv-only")
    if old_intracranial_volume_only:
        cargs.append("--old-etiv-only")
    if talairach_transform is not None:
        cargs.extend([
            "--talxfm",
            execution.input_file(talairach_transform)
        ])
    if xfm_to_etiv is not None:
        cargs.extend([
            "--xfm2etiv",
            xfm_to_etiv
        ])
    if euler_hole_count:
        cargs.append("--euler")
    if avg_waveform is not None:
        cargs.extend([
            "--avgwf",
            avg_waveform
        ])
    if sum_waveform is not None:
        cargs.extend([
            "--sumwf",
            sum_waveform
        ])
    if avg_waveform_vol is not None:
        cargs.extend([
            "--avgwfvol",
            avg_waveform_vol
        ])
    if remove_avgwf_mean:
        cargs.append("--avgwf-remove-mean")
    if spatial_frame_avg is not None:
        cargs.extend([
            "--sfavg",
            spatial_frame_avg
        ])
    if voxel_crs is not None:
        cargs.extend([
            "--vox",
            voxel_crs
        ])
    if replace_ids is not None:
        cargs.extend([
            "--replace",
            replace_ids
        ])
    if replace_ids_file is not None:
        cargs.extend([
            "--replace-file",
            execution.input_file(replace_ids_file)
        ])
    if gtm_default_seg_merge:
        cargs.append("--gtm-default-seg-merge")
    if gtm_default_seg_merge_choroid:
        cargs.append("--gtm-default-seg-merge-choroid")
    if qa_stats_file is not None:
        cargs.extend([
            "--qa-stats",
            qa_stats_file
        ])
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    if random_seed is not None:
        cargs.extend([
            "--seed",
            str(random_seed)
        ])
    ret = MriSegstatsOutputs(
        root=execution.output_file("."),
        summary_output_file=execution.output_file(output_file),
        avg_waveform_output=execution.output_file(avg_waveform) if (avg_waveform is not None) else None,
        sum_waveform_output=execution.output_file(sum_waveform) if (sum_waveform is not None) else None,
        avg_waveform_vol_output=execution.output_file(avg_waveform_vol) if (avg_waveform_vol is not None) else None,
        spatial_frame_avg_output=execution.output_file(spatial_frame_avg) if (spatial_frame_avg is not None) else None,
        ctab_output_file=execution.output_file(ctab_output) if (ctab_output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SEGSTATS_METADATA",
    "MriSegstatsOutputs",
    "mri_segstats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

COMPUTE_LABEL_VOLUMES_CSH_METADATA = Metadata(
    id="82638ae4faa0eb9506df9c2f3a56c833cb5de288.boutiques",
    name="compute_label_volumes.csh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ComputeLabelVolumesCshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `compute_label_volumes_csh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    result_file: OutputPathType
    """Text file with the computed number of voxels and volumes"""


def compute_label_volumes_csh(
    label_vol: InputPathType,
    output_file: str,
    label_l: str | None = None,
    version: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> ComputeLabelVolumesCshOutputs:
    """
    Computes the number of voxels and the volumes of either all or a particular
    label in the input label volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        label_vol: Label volume to be analyzed.
        output_file: Text file where the results are written.
        label_l: The particular label to be analyzed (case-insensitive option).
        version: Print version and exit.
        help_: Print help and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ComputeLabelVolumesCshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(COMPUTE_LABEL_VOLUMES_CSH_METADATA)
    cargs = []
    cargs.append("compute_label_volumes")
    cargs.extend([
        "--vol",
        execution.input_file(label_vol)
    ])
    cargs.extend([
        "--out",
        output_file
    ])
    if label_l is not None:
        cargs.extend([
            "--l",
            label_l
        ])
    if version:
        cargs.append("--version")
    if help_:
        cargs.append("--help")
    ret = ComputeLabelVolumesCshOutputs(
        root=execution.output_file("."),
        result_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "COMPUTE_LABEL_VOLUMES_CSH_METADATA",
    "ComputeLabelVolumesCshOutputs",
    "compute_label_volumes_csh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADJUNCT_IS_LABEL_PY_METADATA = Metadata(
    id="fd161fa6ffe35fb86b826e60d07e867baeceef7c.boutiques",
    name="adjunct_is_label.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AdjunctIsLabelPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `adjunct_is_label_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def adjunct_is_label_py(
    infile: InputPathType,
    label: str,
    runner: Runner | None = None,
) -> AdjunctIsLabelPyOutputs:
    """
    A subsidiary script of the chauffeur_afni suite for label functionalities.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infile: Input file for the adjunct_is_label script.
        label: Output label generated by the script.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AdjunctIsLabelPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADJUNCT_IS_LABEL_PY_METADATA)
    cargs = []
    cargs.append("adjunct_is_label.py")
    cargs.append(execution.input_file(infile))
    cargs.append(label)
    ret = AdjunctIsLabelPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADJUNCT_IS_LABEL_PY_METADATA",
    "AdjunctIsLabelPyOutputs",
    "adjunct_is_label_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_NORMALS_METADATA = Metadata(
    id="bf741b89964614d5dda2065678e1ec762984a361.boutiques",
    name="surface-normals",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceNormalsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_normals(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the normal vectors"""


def surface_normals(
    surface: InputPathType,
    metric_out: str,
    runner: Runner | None = None,
) -> SurfaceNormalsOutputs:
    """
    Output vertex normals as metric file.
    
    Computes the normal vectors of the surface file, and outputs them as a 3
    column metric file.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to output the normals of.
        metric_out: the normal vectors.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceNormalsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_NORMALS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-normals")
    cargs.append(execution.input_file(surface))
    cargs.append(metric_out)
    ret = SurfaceNormalsOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_NORMALS_METADATA",
    "SurfaceNormalsOutputs",
    "surface_normals",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ICC_METADATA = Metadata(
    id="6b7ec5c6de013c42d47420ebf12a564c200ff8a3.boutiques",
    name="3dICC",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dIccOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_icc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Name of the output file"""


def v_3d_icc(
    model: str,
    prefix: str,
    data_table: str,
    mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dIccOutputs:
    """
    AFNI Program for IntraClass Correlatin (ICC) Analysis.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        model: Model structure for all the variables. The expression FORMULA\
            with more than one variable has to be surrounded within quotes.\
            Variable names should be consistent with the ones used in the header of\
            -dataTable.
        prefix: Name of output file. For AFNI format, provide prefix only, with\
            no view+suffix needed. Filename for NIfTI format should have .nii\
            attached, while file name for surface data is expected to end with\
            .niml.dset.
        data_table: List the data structure with a header as the first line.\
            The first column is reserved with label 'Subj', and the last is\
            reserved for 'InputFile'.
        mask: Path to mask file. Only process voxels inside this mask.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dIccOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ICC_METADATA)
    cargs = []
    cargs.append("3dICC")
    cargs.append(model)
    cargs.extend([
        "-prefix",
        prefix
    ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    cargs.extend([
        "-dataTable",
        data_table
    ])
    cargs.append("[OPTIONS]")
    ret = V3dIccOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dIccOutputs",
    "V_3D_ICC_METADATA",
    "v_3d_icc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_COPY_HEADER_METADATA = Metadata(
    id="50aaea9bf37b8cf2e2b611b945681126287cbd83.boutiques",
    name="mris_copy_header",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisCopyHeaderOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_copy_header(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_surface: OutputPathType
    """Output surface file with copied header."""


def mris_copy_header(
    input_surface: InputPathType,
    template_surface: InputPathType,
    output_surface: str,
    runner: Runner | None = None,
) -> MrisCopyHeaderOutputs:
    """
    Tool to copy the header from a template surface to an input surface and save as
    the output surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file whose header will be replaced.
        template_surface: Template surface file from which the header will be\
            copied.
        output_surface: Output surface file with the updated header.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisCopyHeaderOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_COPY_HEADER_METADATA)
    cargs = []
    cargs.append("mris_copy_header")
    cargs.append(execution.input_file(input_surface))
    cargs.append(execution.input_file(template_surface))
    cargs.append(output_surface)
    ret = MrisCopyHeaderOutputs(
        root=execution.output_file("."),
        out_surface=execution.output_file(output_surface),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_COPY_HEADER_METADATA",
    "MrisCopyHeaderOutputs",
    "mris_copy_header",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DPC_METADATA = Metadata(
    id="987590dc34e13c6e990d98f4bc903e998e6cb77f.boutiques",
    name="3dpc",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dpcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dpc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType | None
    """Output dataset file"""
    output_header: OutputPathType | None
    """Output dataset header file"""
    output_eig: OutputPathType | None
    """File with computed eigenvalues"""
    output_vec: OutputPathType | None
    """File with all eigen-timeseries"""
    output_individual_vec: OutputPathType | None
    """File with individual eigenvalue timeseries"""


def v_3dpc(
    datasets: list[InputPathType],
    dmean: bool = False,
    vmean: bool = False,
    vnorm: bool = False,
    normalize: bool = False,
    nscale: bool = False,
    pcsave: str | None = None,
    reduce: list[str] | None = None,
    prefix: str | None = None,
    dummy_lines: int | None = None,
    verbose: bool = False,
    quiet: bool = False,
    eigonly: bool = False,
    float_: bool = False,
    mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dpcOutputs:
    """
    Principal Component Analysis of 3D Datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        datasets: Input dataset(s) with sub-brick selector list support.
        dmean: Remove the mean from each input brick (across space).
        vmean: Remove the mean from each input voxel (across bricks).
        vnorm: L2 normalize each input voxel time series.
        normalize: L2 normalize each input brick (after mean subtraction).
        nscale: Scale the covariance matrix by the number of samples.
        pcsave: 'sss' is the number of components to save in the output.
        reduce: Compute a dimensionally reduced dataset with top 'r'\
            eigenvalues and write to disk in dataset 'pp'.
        prefix: Name for the output dataset.
        dummy_lines: Add 'ddd' dummy lines to the top of each *.1D file.
        verbose: Print progress reports during the computations.
        quiet: Don't print progress reports.
        eigonly: Only compute eigenvalues, write them to 'pname'_eig.1D, then\
            stop.
        float_: Save eigen-bricks as floats (default = shorts).
        mask: Use the 0 sub-brick of dataset 'mset' as a mask indicating which\
            voxels to analyze.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dpcOutputs`).
    """
    if reduce is not None and (len(reduce) != 2): 
        raise ValueError(f"Length of 'reduce' must be 2 but was {len(reduce)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DPC_METADATA)
    cargs = []
    cargs.append("3dpc")
    cargs.extend([execution.input_file(f) for f in datasets])
    if dmean:
        cargs.append("-dmean")
    if vmean:
        cargs.append("-vmean")
    if vnorm:
        cargs.append("-vnorm")
    if normalize:
        cargs.append("-normalize")
    if nscale:
        cargs.append("-nscale")
    if pcsave is not None:
        cargs.extend([
            "-pcsave",
            pcsave
        ])
    if reduce is not None:
        cargs.extend([
            "-reduce",
            *reduce
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if dummy_lines is not None:
        cargs.extend([
            "-1ddum",
            str(dummy_lines)
        ])
    if verbose:
        cargs.append("-verbose")
    if quiet:
        cargs.append("-quiet")
    if eigonly:
        cargs.append("-eigonly")
    if float_:
        cargs.append("-float")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    ret = V3dpcOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
        output_header=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
        output_eig=execution.output_file(prefix + "_eig.1D") if (prefix is not None) else None,
        output_vec=execution.output_file(prefix + "_vec.1D") if (prefix is not None) else None,
        output_individual_vec=execution.output_file(prefix + "[NN].1D") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dpcOutputs",
    "V_3DPC_METADATA",
    "v_3dpc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_PVAL_METADATA = Metadata(
    id="728ce13fea332a59b9d1741e5383247954eba774.boutiques",
    name="3dPval",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dPvalOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_pval(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Output dataset with converted statistical values. Default output filename
    is 'Pval.nii.gz'."""


def v_3d_pval(
    input_dataset: InputPathType,
    zscore: bool = False,
    log2: bool = False,
    log10: bool = False,
    qval: bool = False,
    prefix: str | None = None,
    runner: Runner | None = None,
) -> V3dPvalOutputs:
    """
    Convert a dataset's statistical sub-bricks to p-values or other statistical
    representations.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Input dataset (e.g., InputDataset.nii).
        zscore: Convert statistic to a z-score instead, an N(0,1) deviate that\
            represents the same p-value.
        log2: Convert statistic to -log2(p).
        log10: Convert statistic to -log10(p).
        qval: Convert statistic to a q-value (FDR) instead. This option only\
            works with datasets that have FDR curves inserted in their headers.
        prefix: Prefix name for output file (default name is 'Pval').
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dPvalOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_PVAL_METADATA)
    cargs = []
    cargs.append("3dPval")
    cargs.append(execution.input_file(input_dataset))
    if zscore:
        cargs.append("-zscore")
    if log2:
        cargs.append("-log2")
    if log10:
        cargs.append("-log10")
    if qval:
        cargs.append("-qval")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    ret = V3dPvalOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + ".nii.gz") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dPvalOutputs",
    "V_3D_PVAL_METADATA",
    "v_3d_pval",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_CREATE_PARCELLATED_FROM_TEMPLATE_METADATA = Metadata(
    id="97f1dd5239568c20aee38b5af5601267807ff55f.boutiques",
    name="cifti-create-parcellated-from-template",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiCreateParcellatedFromTemplateCifti:
    """
    specify an input cifti file.
    """
    cifti_in: InputPathType
    """the input parcellated cifti file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cifti")
        cargs.append(execution.input_file(self.cifti_in))
        return cargs


class CiftiCreateParcellatedFromTemplateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_create_parcellated_from_template(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_create_parcellated_from_template(
    cifti_template: InputPathType,
    modify_direction: str,
    cifti_out: str,
    opt_fill_value_value: float | None = None,
    cifti: list[CiftiCreateParcellatedFromTemplateCifti] | None = None,
    runner: Runner | None = None,
) -> CiftiCreateParcellatedFromTemplateOutputs:
    """
    Match parcels to template by name.
    
    For each parcel name in the template mapping, find that name in an input
    cifti file and use its data in the output file. All input cifti files must
    have a parcels mapping along <modify-direction> and matching mappings along
    other dimensions. The direction can be either an integer starting from 1, or
    the strings 'ROW' or 'COLUMN'.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_template: a cifti file with the template parcel mapping along\
            column.
        modify_direction: which dimension of the output file should match the\
            template (integer, 'ROW', or 'COLUMN').
        cifti_out: the output cifti file.
        opt_fill_value_value: specify value to be used in parcels that don't\
            match: value to use (default 0).
        cifti: specify an input cifti file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateParcellatedFromTemplateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CREATE_PARCELLATED_FROM_TEMPLATE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-create-parcellated-from-template")
    cargs.append(execution.input_file(cifti_template))
    cargs.append(modify_direction)
    cargs.append(cifti_out)
    if opt_fill_value_value is not None:
        cargs.extend([
            "-fill-value",
            str(opt_fill_value_value)
        ])
    if cifti is not None:
        cargs.extend([a for c in [s.run(execution) for s in cifti] for a in c])
    ret = CiftiCreateParcellatedFromTemplateOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_CREATE_PARCELLATED_FROM_TEMPLATE_METADATA",
    "CiftiCreateParcellatedFromTemplateCifti",
    "CiftiCreateParcellatedFromTemplateOutputs",
    "cifti_create_parcellated_from_template",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_EXTRACT_LARGEST_CC_METADATA = Metadata(
    id="d482ce41fdae770a9397038906daba39eebb0541.boutiques",
    name="mri_extract_largest_CC",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriExtractLargestCcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_extract_largest_cc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume_file: OutputPathType
    """The output volume with the largest connected component extracted."""


def mri_extract_largest_cc(
    input_volume: InputPathType,
    output_volume: str,
    threshold: float | None = None,
    hemisphere: typing.Literal["lh", "rh"] | None = None,
    largest_cc_in_bg: bool = False,
    original_volume: InputPathType | None = None,
    label_value: float | None = None,
    runner: Runner | None = None,
) -> MriExtractLargestCcOutputs:
    """
    This program extracts the largest connected component of the input volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume.
        output_volume: Output volume.
        threshold: Threshold for object.
        hemisphere: Set the target value corresponding to lh (255) or rh (127).
        largest_cc_in_bg: Find the largest CC in the background.
        original_volume: Clone values from original volume into output (used\
            with -I).
        label_value: Perform connected components on voxels with specified\
            label value.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriExtractLargestCcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_EXTRACT_LARGEST_CC_METADATA)
    cargs = []
    cargs.append("mri_extract_largest_CC")
    cargs.append(execution.input_file(input_volume))
    cargs.append(output_volume)
    if threshold is not None:
        cargs.extend([
            "-T",
            str(threshold)
        ])
    if hemisphere is not None:
        cargs.extend([
            "-hemi",
            hemisphere
        ])
    if largest_cc_in_bg:
        cargs.append("-I")
    if original_volume is not None:
        cargs.extend([
            "-O",
            execution.input_file(original_volume)
        ])
    if label_value is not None:
        cargs.extend([
            "-L",
            str(label_value)
        ])
    ret = MriExtractLargestCcOutputs(
        root=execution.output_file("."),
        output_volume_file=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_EXTRACT_LARGEST_CC_METADATA",
    "MriExtractLargestCcOutputs",
    "mri_extract_largest_cc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TCKRESAMPLE_METADATA = Metadata(
    id="985698dc2451e564202878939f3e4388fbe9d151.boutiques",
    name="tckresample",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class TckresampleLine:
    """
    resample tracks at 'num' equidistant locations along a line between 'start'
    and 'end' (specified as comma-separated 3-vectors in scanner coordinates).
    """
    num: int
    """resample tracks at 'num' equidistant locations along a line between
    'start' and 'end' (specified as comma-separated 3-vectors in scanner
    coordinates)"""
    start: list[float]
    """resample tracks at 'num' equidistant locations along a line between
    'start' and 'end' (specified as comma-separated 3-vectors in scanner
    coordinates)"""
    end: list[float]
    """resample tracks at 'num' equidistant locations along a line between
    'start' and 'end' (specified as comma-separated 3-vectors in scanner
    coordinates)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-line")
        cargs.append(str(self.num))
        cargs.append(",".join(map(str, self.start)))
        cargs.append(",".join(map(str, self.end)))
        return cargs


@dataclasses.dataclass
class TckresampleArc:
    """
    resample tracks at 'num' equidistant locations along a circular arc
    specified by points 'start', 'mid' and 'end' (specified as comma-separated
    3-vectors in scanner coordinates).
    """
    num: int
    """resample tracks at 'num' equidistant locations along a circular arc
    specified by points 'start', 'mid' and 'end' (specified as comma-separated
    3-vectors in scanner coordinates)"""
    start: list[float]
    """resample tracks at 'num' equidistant locations along a circular arc
    specified by points 'start', 'mid' and 'end' (specified as comma-separated
    3-vectors in scanner coordinates)"""
    mid: list[float]
    """resample tracks at 'num' equidistant locations along a circular arc
    specified by points 'start', 'mid' and 'end' (specified as comma-separated
    3-vectors in scanner coordinates)"""
    end: list[float]
    """resample tracks at 'num' equidistant locations along a circular arc
    specified by points 'start', 'mid' and 'end' (specified as comma-separated
    3-vectors in scanner coordinates)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-arc")
        cargs.append(str(self.num))
        cargs.append(",".join(map(str, self.start)))
        cargs.append(",".join(map(str, self.mid)))
        cargs.append(",".join(map(str, self.end)))
        return cargs


@dataclasses.dataclass
class TckresampleConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class TckresampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tckresample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_tracks: OutputPathType
    """the output resampled tracks"""


def tckresample(
    in_tracks: InputPathType,
    out_tracks: str,
    upsample: int | None = None,
    downsample: int | None = None,
    step_size: float | None = None,
    num_points: int | None = None,
    endpoints: bool = False,
    line: TckresampleLine | None = None,
    arc: TckresampleArc | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[TckresampleConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> TckresampleOutputs:
    """
    Resample each streamline in a track file to a new set of vertices.
    
    It is necessary to specify precisely ONE of the command-line options for
    controlling how this resampling takes place; this may be either increasing
    or decreasing the number of samples along each streamline, or may involve
    changing the positions of the samples according to some specified
    trajectory.
    
    Note that because the length of a streamline is calculated based on the sums
    of distances between adjacent vertices, resampling a streamline to a new set
    of vertices will typically change the quantified length of that streamline;
    the magnitude of the difference will typically depend on the discrepancy in
    the number of vertices, with less vertices leading to a shorter length (due
    to taking chordal lengths of curved trajectories).
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        in_tracks: the input track file.
        out_tracks: the output resampled tracks.
        upsample: increase the density of points along the length of each\
            streamline by some factor (may improve mapping streamlines to ROIs,\
            and/or visualisation).
        downsample: increase the density of points along the length of each\
            streamline by some factor (decreases required storage space).
        step_size: re-sample the streamlines to a desired step size (in mm).
        num_points: re-sample each streamline to a fixed number of points.
        endpoints: only output the two endpoints of each streamline.
        line: resample tracks at 'num' equidistant locations along a line\
            between 'start' and 'end' (specified as comma-separated 3-vectors in\
            scanner coordinates).
        arc: resample tracks at 'num' equidistant locations along a circular\
            arc specified by points 'start', 'mid' and 'end' (specified as\
            comma-separated 3-vectors in scanner coordinates).
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TckresampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TCKRESAMPLE_METADATA)
    cargs = []
    cargs.append("tckresample")
    if upsample is not None:
        cargs.extend([
            "-upsample",
            str(upsample)
        ])
    if downsample is not None:
        cargs.extend([
            "-downsample",
            str(downsample)
        ])
    if step_size is not None:
        cargs.extend([
            "-step_size",
            str(step_size)
        ])
    if num_points is not None:
        cargs.extend([
            "-num_points",
            str(num_points)
        ])
    if endpoints:
        cargs.append("-endpoints")
    if line is not None:
        cargs.extend(line.run(execution))
    if arc is not None:
        cargs.extend(arc.run(execution))
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(in_tracks))
    cargs.append(out_tracks)
    ret = TckresampleOutputs(
        root=execution.output_file("."),
        out_tracks=execution.output_file(out_tracks),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TCKRESAMPLE_METADATA",
    "TckresampleArc",
    "TckresampleConfig",
    "TckresampleLine",
    "TckresampleOutputs",
    "tckresample",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_EASYREG_METADATA = Metadata(
    id="a8597c7c31eb3d0db090b8c58b2eb2709f8b9b2d.boutiques",
    name="mri_easyreg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriEasyregOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_easyreg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    registered_reference_output: OutputPathType
    """Output registered reference image"""
    registered_floating_output: OutputPathType
    """Output registered floating image"""
    forward_field_output: OutputPathType
    """Output forward field file"""
    inverse_field_output: OutputPathType
    """Output inverse field file"""


def mri_easyreg(
    reference_image: InputPathType,
    floating_image: InputPathType,
    reference_segmentation: InputPathType | None = None,
    floating_segmentation: InputPathType | None = None,
    registered_reference: InputPathType | None = None,
    registered_floating: InputPathType | None = None,
    forward_field: InputPathType | None = None,
    inverse_field: InputPathType | None = None,
    affine_only: bool = False,
    threads: float | None = None,
    runner: Runner | None = None,
) -> MriEasyregOutputs:
    """
    EasyReg: deep learning registration simple and easy.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        reference_image: Reference image.
        floating_image: Floating image.
        reference_segmentation: Reference SynthSeg segmentation (will be\
            created if it does not exist).
        floating_segmentation: Floating SynthSeg segmentation (will be created\
            if it does not exist).
        registered_reference: (optional) Registered reference.
        registered_floating: (optional) Registered floating images (in space of\
            reference).
        forward_field: (optional) Forward field.
        inverse_field: (optional) Inverse field.
        affine_only: (optional) Skips nonlinear part.
        threads: (optional) Number of cores to be used. Default is 1. You can\
            use -1 to use all available cores.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriEasyregOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_EASYREG_METADATA)
    cargs = []
    cargs.append("mri_easyreg")
    cargs.extend([
        "--ref",
        execution.input_file(reference_image)
    ])
    if reference_segmentation is not None:
        cargs.extend([
            "--ref_seg",
            execution.input_file(reference_segmentation)
        ])
    cargs.extend([
        "--flo",
        execution.input_file(floating_image)
    ])
    if floating_segmentation is not None:
        cargs.extend([
            "--flo_seg",
            execution.input_file(floating_segmentation)
        ])
    if registered_reference is not None:
        cargs.extend([
            "--ref_reg",
            execution.input_file(registered_reference)
        ])
    if registered_floating is not None:
        cargs.extend([
            "--flo_reg",
            execution.input_file(registered_floating)
        ])
    if forward_field is not None:
        cargs.extend([
            "--fwd_field",
            execution.input_file(forward_field)
        ])
    if inverse_field is not None:
        cargs.extend([
            "--bak_field",
            execution.input_file(inverse_field)
        ])
    if affine_only:
        cargs.append("--affine_only")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    ret = MriEasyregOutputs(
        root=execution.output_file("."),
        registered_reference_output=execution.output_file("registered_reference.nii.gz"),
        registered_floating_output=execution.output_file("registered_floating.nii.gz"),
        forward_field_output=execution.output_file("forward_field.nii.gz"),
        inverse_field_output=execution.output_file("inverse_field.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_EASYREG_METADATA",
    "MriEasyregOutputs",
    "mri_easyreg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SHCONV_METADATA = Metadata(
    id="3c84c5743ea66d880048dc5dc975db440966a75e.boutiques",
    name="shconv",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class ShconvVariousString:
    obj: str
    """String object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(self.obj)
        return cargs


@dataclasses.dataclass
class ShconvVariousFile:
    obj: InputPathType
    """File object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.obj))
        return cargs


@dataclasses.dataclass
class ShconvConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class ShconvOutputs(typing.NamedTuple):
    """
    Output object returned when calling `shconv(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    sh_out: OutputPathType
    """the output spherical harmonics coefficients image."""


def shconv(
    odf_response: list[str],
    sh_out: str,
    datatype: str | None = None,
    strides: typing.Union[ShconvVariousString, ShconvVariousFile] | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[ShconvConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> ShconvOutputs:
    """
    Perform spherical convolution.
    
    Provided with matching pairs of response function and ODF images (containing
    SH coefficients), perform spherical convolution to provide the corresponding
    SH coefficients of the signal.
    
    If multiple pairs of inputs are provided, their contributions will be summed
    into a single output.
    
    If the responses are multi-shell (with one line of coefficients per shell),
    the output will be a 5-dimensional image, with the SH coefficients of the
    signal in each shell stored at different indices along the 5th dimension.
    
    The spherical harmonic coefficients are stored according the conventions
    described the main documentation, which can be found at the following link:
    https://mrtrix.readthedocs.io/en/3.0.4/concepts/spherical_harmonics.html
    
    The spherical harmonic coefficients are stored according the conventions
    described the main documentation, which can be found at the following link:
    https://mrtrix.readthedocs.io/en/3.0.4/concepts/spherical_harmonics.html
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        odf_response: pairs of input ODF image and corresponding responses.
        sh_out: the output spherical harmonics coefficients image.
        datatype: specify output image data type. Valid choices are: float32,\
            float32le, float32be, float64, float64le, float64be, int64, uint64,\
            int64le, uint64le, int64be, uint64be, int32, uint32, int32le, uint32le,\
            int32be, uint32be, int16, uint16, int16le, uint16le, int16be, uint16be,\
            cfloat32, cfloat32le, cfloat32be, cfloat64, cfloat64le, cfloat64be,\
            int8, uint8, bit.
        strides: specify the strides of the output data in memory; either as a\
            comma-separated list of (signed) integers, or as a template image from\
            which the strides shall be extracted and used. The actual strides\
            produced will depend on whether the output image format can support it.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ShconvOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SHCONV_METADATA)
    cargs = []
    cargs.append("shconv")
    if datatype is not None:
        cargs.extend([
            "-datatype",
            datatype
        ])
    if strides is not None:
        cargs.extend([
            "-strides",
            *strides.run(execution)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.extend(odf_response)
    cargs.append(sh_out)
    ret = ShconvOutputs(
        root=execution.output_file("."),
        sh_out=execution.output_file(sh_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SHCONV_METADATA",
    "ShconvConfig",
    "ShconvOutputs",
    "ShconvVariousFile",
    "ShconvVariousString",
    "shconv",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_MOTION_CORR_DIFFUSION_DIRECTION_METADATA = Metadata(
    id="3f81491f1faf2e11f2fe0e69121f28544825a2d4.boutiques",
    name="antsMotionCorrDiffusionDirection",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsMotionCorrDiffusionDirectionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_motion_corr_diffusion_direction(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_scheme: OutputPathType
    """The output file for corrected diffusion directions."""


def ants_motion_corr_diffusion_direction(
    scheme: InputPathType,
    bvec: InputPathType,
    physical: InputPathType,
    moco: InputPathType,
    output: str,
    runner: Runner | None = None,
) -> AntsMotionCorrDiffusionDirectionOutputs:
    """
    This tool adjusts the diffusion scheme for motion correction.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        scheme: Camino scheme file specify acquisition parameters.
        bvec: bvec image specifying diffusion directions.
        physical: 3D image in dwi space.
        moco: Motion correction parameters from antsMotionCorr.
        output: Specify the output file for corrected directions.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsMotionCorrDiffusionDirectionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_MOTION_CORR_DIFFUSION_DIRECTION_METADATA)
    cargs = []
    cargs.append("antsMotionCorrDiffusionDirection")
    cargs.extend([
        "-s",
        execution.input_file(scheme)
    ])
    cargs.extend([
        "-b",
        execution.input_file(bvec)
    ])
    cargs.extend([
        "-p",
        execution.input_file(physical)
    ])
    cargs.extend([
        "-m",
        execution.input_file(moco)
    ])
    cargs.extend([
        "-o",
        output
    ])
    ret = AntsMotionCorrDiffusionDirectionOutputs(
        root=execution.output_file("."),
        corrected_scheme=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_MOTION_CORR_DIFFUSION_DIRECTION_METADATA",
    "AntsMotionCorrDiffusionDirectionOutputs",
    "ants_motion_corr_diffusion_direction",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ZCAT_METADATA = Metadata(
    id="a00d1d033ba00163e081549b0d7b74b2c667d65a.boutiques",
    name="3dZcat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dZcatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_zcat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_head: OutputPathType | None
    """AFNI HEAD file of the output dataset"""
    out_brik: OutputPathType | None
    """AFNI BRIK file of the output dataset"""


def v_3d_zcat(
    input_files: list[InputPathType],
    prefix: str | None = None,
    datum: typing.Literal["byte", "short", "float"] | None = None,
    fscale: bool = False,
    nscale: bool = False,
    verb: bool = False,
    frugal: bool = False,
    runner: Runner | None = None,
) -> V3dZcatOutputs:
    """
    Concatenates datasets in the slice (z) direction.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: Input datasets.
        prefix: Use 'pname' for the output dataset prefix name.\
            [default='zcat'].
        datum: Coerce the output data to be stored as the given type, which may\
            be byte, short, or float.
        fscale: Force scaling of the output to the maximum integer range. This\
            only has effect if the output datum is byte or short (either forced or\
            defaulted). This option is sometimes necessary to eliminate unpleasant\
            truncation artifacts.
        nscale: Don't do any scaling on output to byte or short datasets. This\
            may be especially useful when operating on mask datasets whose output\
            values are only 0's and 1's.
        verb: Print out some verbosity as the program proceeds.
        frugal: Be 'frugal' in the use of memory, at the cost of I/O time. Only\
            needed if the program runs out of memory. Note frugality cannot be\
            combined with NIFTI output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dZcatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ZCAT_METADATA)
    cargs = []
    cargs.append("3dZcat")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if datum is not None:
        cargs.extend([
            "-datum",
            datum
        ])
    if fscale:
        cargs.append("-fscale")
    if nscale:
        cargs.append("-nscale")
    if verb:
        cargs.append("-verb")
    if frugal:
        cargs.append("-frugal")
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = V3dZcatOutputs(
        root=execution.output_file("."),
        out_head=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
        out_brik=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dZcatOutputs",
    "V_3D_ZCAT_METADATA",
    "v_3d_zcat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_STATS_METADATA = Metadata(
    id="0f47bef41c97110888e59c7cfd3037199cf66fa3.boutiques",
    name="cifti-stats",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiStatsRoi:
    """
    only consider data inside an roi.
    """
    roi_cifti: InputPathType
    """the roi, as a cifti file"""
    opt_match_maps: bool = False
    """each column of input uses the corresponding column from the roi file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-roi")
        cargs.append(execution.input_file(self.roi_cifti))
        if self.opt_match_maps:
            cargs.append("-match-maps")
        return cargs


class CiftiStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_stats(
    cifti_in: InputPathType,
    opt_reduce_operation: str | None = None,
    opt_percentile_percent: float | None = None,
    opt_column_column: int | None = None,
    roi: CiftiStatsRoi | None = None,
    opt_show_map_name: bool = False,
    runner: Runner | None = None,
) -> CiftiStatsOutputs:
    """
    Statistics along cifti columns.
    
    For each column of the input, a line of text is printed, resulting from the
    specified reduction or percentile operation. If -roi is specified without
    -match-maps, then each line will contain as many numbers as there are maps
    in the ROI file, separated by tab characters. Use -column to only give
    output for a single data column. Exactly one of -reduce or -percentile must
    be specified.
    
    The argument to the -reduce option must be one of the following:
    
    MAX: the maximum value
    MIN: the minimum value
    INDEXMAX: the 1-based index of the maximum value
    INDEXMIN: the 1-based index of the minimum value
    SUM: add all values
    PRODUCT: multiply all values
    MEAN: the mean of the data
    STDEV: the standard deviation (N denominator)
    SAMPSTDEV: the sample standard deviation (N-1 denominator)
    VARIANCE: the variance of the data
    TSNR: mean divided by sample standard deviation (N-1 denominator)
    COV: sample standard deviation (N-1 denominator) divided by mean
    L2NORM: square root of sum of squares
    MEDIAN: the median of the data
    MODE: the mode of the data
    COUNT_NONZERO: the number of nonzero elements in the data
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the input cifti.
        opt_reduce_operation: use a reduction operation: the reduction\
            operation.
        opt_percentile_percent: give the value at a percentile: the percentile\
            to find, must be between 0 and 100.
        opt_column_column: only display output for one column: the column index\
            (starting from 1).
        roi: only consider data inside an roi.
        opt_show_map_name: print column index and name before each output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_STATS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-stats")
    cargs.append(execution.input_file(cifti_in))
    if opt_reduce_operation is not None:
        cargs.extend([
            "-reduce",
            opt_reduce_operation
        ])
    if opt_percentile_percent is not None:
        cargs.extend([
            "-percentile",
            str(opt_percentile_percent)
        ])
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            str(opt_column_column)
        ])
    if roi is not None:
        cargs.extend(roi.run(execution))
    if opt_show_map_name:
        cargs.append("-show-map-name")
    ret = CiftiStatsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_STATS_METADATA",
    "CiftiStatsOutputs",
    "CiftiStatsRoi",
    "cifti_stats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DJUNCT_MODAL_SMOOTHING_WITH_REP_METADATA = Metadata(
    id="3dfe64fe4b416974b4aa2cc3b180143c7a5ada1d.boutiques",
    name="@djunct_modal_smoothing_with_rep",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDjunctModalSmoothingWithRepOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__djunct_modal_smoothing_with_rep(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file_head: OutputPathType
    """Output dataset after modal smoothing"""
    output_file_brik: OutputPathType
    """Output dataset after modal smoothing"""


def v__djunct_modal_smoothing_with_rep(
    input_file: InputPathType,
    output_prefix: str,
    modesmooth: float | None = None,
    help_view: bool = False,
    help_: bool = False,
    version: bool = False,
    overwrite: bool = False,
    no_clean: bool = False,
    runner: Runner | None = None,
) -> VDjunctModalSmoothingWithRepOutputs:
    """
    A script to perform modal smoothing of ROI maps and check for eliminated ROIs.
    If any ROIs are eliminated during smoothing, they are restored, potentially in a
    degraded form.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_file: Input dataset (assumes < 10^5 subbricks).
        output_prefix: Prefix for output dataset.
        modesmooth: Fill in X in: 3dLocalstat -nbhd "SPHERE(-X)" ...
        help_view: Display help in a viewable format.
        help_: Display help information.
        version: Display version information.
        overwrite: Overwrite existing output files.
        no_clean: Do not clean up intermediate files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDjunctModalSmoothingWithRepOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DJUNCT_MODAL_SMOOTHING_WITH_REP_METADATA)
    cargs = []
    cargs.append("@djunct_modal_smoothing_with_rep")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_prefix)
    if modesmooth is not None:
        cargs.extend([
            "-modesmooth",
            str(modesmooth)
        ])
    if help_view:
        cargs.append("-hview")
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-ver")
    if overwrite:
        cargs.append("-overwrite")
    if no_clean:
        cargs.append("-no_clean")
    ret = VDjunctModalSmoothingWithRepOutputs(
        root=execution.output_file("."),
        output_file_head=execution.output_file(output_prefix + "+tlrc.HEAD"),
        output_file_brik=execution.output_file(output_prefix + "+tlrc.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDjunctModalSmoothingWithRepOutputs",
    "V__DJUNCT_MODAL_SMOOTHING_WITH_REP_METADATA",
    "v__djunct_modal_smoothing_with_rep",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMMASK_METADATA = Metadata(
    id="9c1f93c0cb09202023e9490b9f3feb5a319f6f59.boutiques",
    name="immask",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ImmaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `immask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Masked output image"""


def immask(
    input_image: InputPathType,
    output_image: str,
    threshold: float | None = None,
    mask_image: InputPathType | None = None,
    positive_only: bool = False,
    runner: Runner | None = None,
) -> ImmaskOutputs:
    """
    Masks the input image based on specified criteria and produces the output image.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_image: Input image to be masked.
        output_image: Output image after masking.
        threshold: Threshold value; all pixels with absolute value below this\
            will be set to zero in the output image.
        mask_image: Mask image; only locations that are nonzero in the mask\
            image will be nonzero in the output image.
        positive_only: Use only positive pixels from input image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImmaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMMASK_METADATA)
    cargs = []
    cargs.append("immask")
    if threshold is not None:
        cargs.extend([
            "-thresh",
            str(threshold)
        ])
    if mask_image is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_image)
        ])
    if positive_only:
        cargs.append("-pos")
    cargs.append(execution.input_file(input_image))
    cargs.append(output_image)
    ret = ImmaskOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_image),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMMASK_METADATA",
    "ImmaskOutputs",
    "immask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FNAME2EXT_METADATA = Metadata(
    id="d737533f13debab7b8cdf915ca9c4aa939e7445c.boutiques",
    name="fname2ext",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Fname2extOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fname2ext(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    file_extension: OutputPathType
    """Extracted file extension"""


def fname2ext(
    filename: str,
    runner: Runner | None = None,
) -> Fname2extOutputs:
    """
    Converts the name of a file to its extension.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        filename: The name of the file for which to extract the extension. The\
            file does not need to exist.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fname2extOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FNAME2EXT_METADATA)
    cargs = []
    cargs.append("fname2ext")
    cargs.append(filename)
    ret = Fname2extOutputs(
        root=execution.output_file("."),
        file_extension=execution.output_file("extension.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FNAME2EXT_METADATA",
    "Fname2extOutputs",
    "fname2ext",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_VOL2SURF_METADATA = Metadata(
    id="9b1f4f0a610312351db96a33b3de116be9ef57ae.boutiques",
    name="mri_vol2surf",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriVol2surfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_vol2surf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    resampled_volume_output: OutputPathType
    """Output file containing the resampled volume onto the surface"""


def mri_vol2surf(
    input_volume: InputPathType,
    registration_file: InputPathType,
    output_path: str,
    reference_volume: str | None = None,
    regheader_subject: str | None = None,
    mni152reg_flag: bool = False,
    target_subject: str | None = None,
    hemisphere: typing.Literal["lh", "rh"] | None = None,
    surface: str | None = None,
    runner: Runner | None = None,
) -> MriVol2surfOutputs:
    """
    This program resamples a volume onto a surface of a subject or the sphere. The
    output can be viewed on the surface (using tksurfer) or can be used for
    surface-based intersubject averaging.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Path to input volume file.
        registration_file: Registration file as computed by tkregister,\
            spmregister, bbregister, etc.
        output_path: Output path for the resampled volume.
        reference_volume: Reference volume name, default is orig.mgz.
        regheader_subject: Compute registration from header information,\
            aligning the current volume with the subject/mri/orig.mgz.
        mni152reg_flag: Use MNI152 registration:\
            $FREESURFER_HOME/average/mni152.register.dat.
        target_subject: Target subject for resampling, can be a subject name or\
            'ico' for icosahedron.
        hemisphere: Hemisphere to process: lh = left hemisphere or rh = right\
            hemisphere.
        surface: Target surface on which to resample, default is 'white'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriVol2surfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_VOL2SURF_METADATA)
    cargs = []
    cargs.append("mri_vol2surf")
    cargs.extend([
        "--mov",
        execution.input_file(input_volume)
    ])
    cargs.extend([
        "--reg",
        execution.input_file(registration_file)
    ])
    cargs.extend([
        "--o",
        output_path
    ])
    if reference_volume is not None:
        cargs.extend([
            "--ref",
            reference_volume
        ])
    if regheader_subject is not None:
        cargs.extend([
            "--regheader",
            regheader_subject
        ])
    if mni152reg_flag:
        cargs.append("--mni152reg")
    if target_subject is not None:
        cargs.extend([
            "--trgsubject",
            target_subject
        ])
    if hemisphere is not None:
        cargs.extend([
            "--hemi",
            hemisphere
        ])
    if surface is not None:
        cargs.extend([
            "--surf",
            surface
        ])
    ret = MriVol2surfOutputs(
        root=execution.output_file("."),
        resampled_volume_output=execution.output_file(output_path),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_VOL2SURF_METADATA",
    "MriVol2surfOutputs",
    "mri_vol2surf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_AFNITO_RAW_METADATA = Metadata(
    id="67bff5ed68a691d8da5e7aa97ecf946e7772101e.boutiques",
    name="3dAFNItoRaw",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAfnitoRawOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_afnito_raw(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_afnito_raw(
    dataset: str,
    output_file: str | None = None,
    force_float: bool = False,
    runner: Runner | None = None,
) -> V3dAfnitoRawOutputs:
    """
    Convert an AFNI brik file with multiple sub-briks to a raw file with each
    sub-brik voxel concatenated voxel-wise.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset: Input AFNI dataset with possible modifiers for sub-brick and\
            sub-range selection.
        output_file: Name of the output file (not an AFNI dataset prefix).\
            Default is rawxyz.dat.
        force_float: Force floating point output. Floating point forced if any\
            sub-brik scale factors not equal to 1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAfnitoRawOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_AFNITO_RAW_METADATA)
    cargs = []
    cargs.append("3dAFNItoRaw")
    if output_file is not None:
        cargs.extend([
            "-output",
            output_file
        ])
    if force_float:
        cargs.append("-datum float")
    cargs.append(dataset)
    ret = V3dAfnitoRawOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAfnitoRawOutputs",
    "V_3D_AFNITO_RAW_METADATA",
    "v_3d_afnito_raw",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRMETRIC_METADATA = Metadata(
    id="68993bab707571cc9c043c8d06d2a16330445585.boutiques",
    name="mrmetric",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class MrmetricConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class MrmetricOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mrmetric(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mrmetric(
    image1: InputPathType,
    image2: InputPathType,
    space: str | None = None,
    interp: str | None = None,
    metric: str | None = None,
    mask1: InputPathType | None = None,
    mask2: InputPathType | None = None,
    nonormalisation: bool = False,
    overlap: bool = False,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[MrmetricConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MrmetricOutputs:
    """
    Computes a dissimilarity metric between two images.
    
    Currently only the mean squared difference is fully implemented.
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        image1: the first input image.
        image2: the second input image.
        space: voxel (default): per voxel image1: scanner space of image 1\
            image2: scanner space of image 2 average: scanner space of the average\
            affine transformation of image 1 and 2.
        interp: set the interpolation method to use when reslicing (choices:\
            nearest, linear, cubic, sinc. Default: linear).
        metric: define the dissimilarity metric used to calculate the cost.\
            Choices: diff (squared differences), cc (non-normalised negative cross\
            correlation aka negative cross covariance). Default: diff). cc is only\
            implemented for -space average and -interp linear and cubic.
        mask1: mask for image 1.
        mask2: mask for image 2.
        nonormalisation: do not normalise the dissimilarity metric to the\
            number of voxels.
        overlap: output number of voxels that were used.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrmetricOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRMETRIC_METADATA)
    cargs = []
    cargs.append("mrmetric")
    if space is not None:
        cargs.extend([
            "-space",
            space
        ])
    if interp is not None:
        cargs.extend([
            "-interp",
            interp
        ])
    if metric is not None:
        cargs.extend([
            "-metric",
            metric
        ])
    if mask1 is not None:
        cargs.extend([
            "-mask1",
            execution.input_file(mask1)
        ])
    if mask2 is not None:
        cargs.extend([
            "-mask2",
            execution.input_file(mask2)
        ])
    if nonormalisation:
        cargs.append("-nonormalisation")
    if overlap:
        cargs.append("-overlap")
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(image1))
    cargs.append(execution.input_file(image2))
    ret = MrmetricOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRMETRIC_METADATA",
    "MrmetricConfig",
    "MrmetricOutputs",
    "mrmetric",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BET_FSL_METADATA = Metadata(
    id="05134dd9049bee70d91cad11059af4110900a569.boutiques",
    name="bet.fsl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class BetFslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `bet_fsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Main default mask output of BET"""
    binary_mask: OutputPathType
    """Binary mask file (from -m option)"""
    overlay_file: OutputPathType
    """Overlaid brain surface onto original image"""
    approx_skull_img: OutputPathType
    """Approximate skull image file"""
    output_vtk_mesh: OutputPathType
    """Mesh in VTK format"""
    skull_mask: OutputPathType
    """Output mask for skull image"""
    out_inskull_mask: OutputPathType
    """The in-skull mask file from betsurf"""
    out_inskull_mesh: OutputPathType
    """The in-skull mesh file from betsurf"""
    out_inskull_off: OutputPathType
    """The in-skull mesh .off file from betsurf"""
    out_outskin_mask: OutputPathType
    """The out-skin mask file from betsurf"""
    out_outskin_mesh: OutputPathType
    """The out-skin mesh file from betsurf"""
    out_outskin_off: OutputPathType
    """The out-skin mesh .off file from betsurf"""
    out_outskull_mask: OutputPathType
    """The out-skull mask file from betsurf"""
    out_outskull_mesh: OutputPathType
    """The out-skull mesh file from betsurf"""
    out_outskull_off: OutputPathType
    """The out-skull mesh .off file from betsurf"""


def bet_fsl(
    infile: InputPathType,
    maskfile: str = "img_bet",
    fractional_intensity: float | None = None,
    vg_fractional_intensity: float | None = None,
    center_of_gravity: list[float] | None = None,
    overlay: bool = False,
    binary_mask: bool = False,
    approx_skull: bool = False,
    no_seg_output: bool = False,
    vtk_mesh: bool = False,
    head_radius: float | None = None,
    thresholding: bool = False,
    robust_iters: bool = False,
    residual_optic_cleanup: bool = False,
    reduce_bias: bool = False,
    slice_padding: bool = False,
    whole_set_mask: bool = False,
    additional_surfaces: bool = False,
    additional_surfaces_t2: InputPathType | None = None,
    verbose: bool = False,
    debug: bool = False,
    runner: Runner | None = None,
) -> BetFslOutputs:
    """
    Automated brain extraction tool for FSL.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        infile: Input image (e.g. img.nii.gz).
        maskfile: Output brain mask (e.g. img_bet.nii.gz).
        fractional_intensity: Fractional intensity threshold (0->1);\
            default=0.5; smaller values give larger brain outline estimates.
        vg_fractional_intensity: Vertical gradient in fractional intensity\
            threshold (-1->1); default=0; positive values give larger brain outline\
            at bottom, smaller at top.
        center_of_gravity: The xyz coordinates of the center of gravity\
            (voxels, not mm) of initial mesh surface. Must have exactly three\
            numerical entries in the list (3-vector).
        overlay: Generate brain surface outline overlaid onto original image.
        binary_mask: Generate binary brain mask.
        approx_skull: Generate approximate skull image.
        no_seg_output: Don't generate segmented brain image output.
        vtk_mesh: Generate brain surface as mesh in .vtk format.
        head_radius: Head radius (mm not voxels); initial surface sphere is set\
            to half of this.
        thresholding: Apply thresholding to segmented brain image and mask.
        robust_iters: Robust brain centre estimation (iterates BET several\
            times).
        residual_optic_cleanup: Eye & optic nerve cleanup (can be useful in\
            SIENA).
        reduce_bias: Bias field & neck cleanup (can be useful in SIENA).
        slice_padding: Improve BET if FOV is very small in Z (by temporarily\
            padding end slices).
        whole_set_mask: Apply to 4D FMRI data (uses -f 0.3 and dilates brain\
            mask slightly).
        additional_surfaces: Run bet2 and then betsurf to get additional skull\
            and scalp surfaces (includes registrations).
        additional_surfaces_t2: As with -A, when also feeding in\
            non-brain-extracted T2 (includes registrations).
        verbose: Verbose (switch on diagnostic messages).
        debug: Debug (don't delete temporary intermediate images).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BetFslOutputs`).
    """
    if fractional_intensity is not None and not (0 <= fractional_intensity <= 1): 
        raise ValueError(f"'fractional_intensity' must be between 0 <= x <= 1 but was {fractional_intensity}")
    if vg_fractional_intensity is not None and not (-1 <= vg_fractional_intensity <= 1): 
        raise ValueError(f"'vg_fractional_intensity' must be between -1 <= x <= 1 but was {vg_fractional_intensity}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(BET_FSL_METADATA)
    cargs = []
    cargs.append("bet.fsl")
    cargs.append(execution.input_file(infile))
    cargs.append(maskfile)
    if fractional_intensity is not None:
        cargs.extend([
            "-f",
            str(fractional_intensity)
        ])
    if vg_fractional_intensity is not None:
        cargs.extend([
            "-g",
            str(vg_fractional_intensity)
        ])
    if center_of_gravity is not None:
        cargs.extend([
            "-c",
            *map(str, center_of_gravity)
        ])
    if overlay:
        cargs.append("-o")
    if binary_mask:
        cargs.append("-m")
    if approx_skull:
        cargs.append("-s")
    if no_seg_output:
        cargs.append("-n")
    if vtk_mesh:
        cargs.append("-e")
    if head_radius is not None:
        cargs.extend([
            "-r",
            str(head_radius)
        ])
    if thresholding:
        cargs.append("-t")
    if robust_iters:
        cargs.append("-R")
    if residual_optic_cleanup:
        cargs.append("-S")
    if reduce_bias:
        cargs.append("-B")
    if slice_padding:
        cargs.append("-Z")
    if whole_set_mask:
        cargs.append("-F")
    if additional_surfaces:
        cargs.append("-A")
    if additional_surfaces_t2 is not None:
        cargs.extend([
            "-A2",
            execution.input_file(additional_surfaces_t2)
        ])
    if verbose:
        cargs.append("-v")
    if debug:
        cargs.append("-d")
    ret = BetFslOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(maskfile + ".nii.gz"),
        binary_mask=execution.output_file(maskfile + "_mask.nii.gz"),
        overlay_file=execution.output_file(maskfile + "_overlay.nii.gz"),
        approx_skull_img=execution.output_file(maskfile + "_skull.nii.gz"),
        output_vtk_mesh=execution.output_file(maskfile + "_mesh.vtk"),
        skull_mask=execution.output_file(maskfile + "_skull_mask.nii.gz"),
        out_inskull_mask=execution.output_file(maskfile + "_inskull_mask.nii.gz"),
        out_inskull_mesh=execution.output_file(maskfile + "_inskull_mesh.nii.gz"),
        out_inskull_off=execution.output_file(maskfile + "_inskull_mesh.off"),
        out_outskin_mask=execution.output_file(maskfile + "_outskin_mask.nii.gz"),
        out_outskin_mesh=execution.output_file(maskfile + "_outskin_mesh.nii.gz"),
        out_outskin_off=execution.output_file(maskfile + "_outskin_mesh.off"),
        out_outskull_mask=execution.output_file(maskfile + "_outskull_mask.nii.gz"),
        out_outskull_mesh=execution.output_file(maskfile + "_outskull_mesh.nii.gz"),
        out_outskull_off=execution.output_file(maskfile + "_outskull_mesh.off"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BET_FSL_METADATA",
    "BetFslOutputs",
    "bet_fsl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_COMPILE_EDITS_METADATA = Metadata(
    id="2f294d33e927de222c7f1e4b43430f1f824c2840.boutiques",
    name="mri_compile_edits",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriCompileEditsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_compile_edits(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    compiled_edit_volume: OutputPathType
    """Compiled volume showing all the edits"""


def mri_compile_edits(
    subject_name: str,
    output_volume: str,
    runner: Runner | None = None,
) -> MriCompileEditsOutputs:
    """
    Program to create a single volume showing all the volumetric edits made to a
    subject.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Subject name whose edits are to be compiled into a volume.
        output_volume: Output volume file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriCompileEditsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_COMPILE_EDITS_METADATA)
    cargs = []
    cargs.append("mri_compile_edits")
    cargs.append(subject_name)
    cargs.append(output_volume)
    ret = MriCompileEditsOutputs(
        root=execution.output_file("."),
        compiled_edit_volume=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_COMPILE_EDITS_METADATA",
    "MriCompileEditsOutputs",
    "mri_compile_edits",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_COMPUTE_OVERLAP_METADATA = Metadata(
    id="97d8d567d0e1c761a649f9ba5d647b7d4352a61b.boutiques",
    name="mri_compute_overlap",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriComputeOverlapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_compute_overlap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_compute_overlap(
    volumes: list[InputPathType],
    label_numbers: list[str] | None = None,
    all_labels: bool = False,
    show_label: bool = False,
    total_overlap: bool = False,
    no_summary: bool = False,
    mask: InputPathType | None = None,
    output_file: str | None = None,
    quiet_mode: bool = False,
    translate_label: list[float] | None = None,
    help_: bool = False,
    runner: Runner | None = None,
) -> MriComputeOverlapOutputs:
    """
    Computes three different types of overlap measures for labels in input volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        volumes: Input volume files for which overlap measures are computed.
        label_numbers: List of specific label numbers for which to compute\
            overlap measures. If not specified, all labels are considered if -a is\
            provided.
        all_labels: Compute overlap for all labels.
        show_label: Show label name for segmentation.
        total_overlap: Compute the total overlap, which is the number of voxels\
            that are the same among all labels.
        no_summary: Do not compute total label summary.
        mask: Limit the domain of the calculation to the nonzero voxels in\
            specified volume.
        output_file: Filename to write results to.
        quiet_mode: Do not display results on standard display. If -l is\
            specified, this flag is automatically set.
        translate_label: Translate label l1 to label l2.
        help_: Print help.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriComputeOverlapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_COMPUTE_OVERLAP_METADATA)
    cargs = []
    cargs.append("mri_compute_overlap")
    cargs.extend([execution.input_file(f) for f in volumes])
    if label_numbers is not None:
        cargs.extend(label_numbers)
    if all_labels:
        cargs.append("-a")
    if show_label:
        cargs.append("-s")
    if total_overlap:
        cargs.append("-total")
    if no_summary:
        cargs.append("-nosummary")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if output_file is not None:
        cargs.extend([
            "-l",
            output_file
        ])
    if quiet_mode:
        cargs.append("-q")
    if translate_label is not None:
        cargs.extend([
            "-t",
            *map(str, translate_label)
        ])
    if help_:
        cargs.append("-h")
    ret = MriComputeOverlapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_COMPUTE_OVERLAP_METADATA",
    "MriComputeOverlapOutputs",
    "mri_compute_overlap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INFLATE_SUBJECT_RH_METADATA = Metadata(
    id="c870a2dd4beffc1dccf8c6c63c1951a8bb440f30.boutiques",
    name="inflate_subject-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class InflateSubjectRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `inflate_subject_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def inflate_subject_rh(
    arguments: str | None = None,
    runner: Runner | None = None,
) -> InflateSubjectRhOutputs:
    """
    Freesurfer command to perform an operation on the right hemisphere of a
    subject's brain image data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        arguments: Arguments for the command. Placeholder due to lack of\
            detailed help text.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InflateSubjectRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INFLATE_SUBJECT_RH_METADATA)
    cargs = []
    if arguments is not None:
        cargs.extend([
            "-rh",
            "inflate_subject" + arguments
        ])
    ret = InflateSubjectRhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INFLATE_SUBJECT_RH_METADATA",
    "InflateSubjectRhOutputs",
    "inflate_subject_rh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_PROC_DECMAP_METADATA = Metadata(
    id="a736dc72fa9ccb8800e84305855b09096c833b1d.boutiques",
    name="fat_proc_decmap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatProcDecmapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_proc_decmap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile_dec_rgb: OutputPathType
    """Single file of type 'rgb' for RGB coloration display."""
    outfile_dec_unwt_thr: OutputPathType
    """Single file of type 'rgb' without FA weighting but using FA to threshold
    where DEC values are calculated."""
    outfile_dec_sca: OutputPathType
    """DEC file additionally scaled by a value (such as 0.7)."""
    qc_dec_images: OutputPathType
    """Set of cor, axi, and sag images (each a 5x3 montage) of the DEC data."""
    qc_dec_unwt_thrx_images: OutputPathType
    """Set of cor, axi, and sag images (each a 5x3 montage) of the DEC
    unweighted thresholded data."""
    qc_dec_sca_images: OutputPathType
    """Set of cor, axi, and sag images (each a 5x3 montage) of the DEC scaled
    data."""


def fat_proc_decmap(
    in_fa: InputPathType,
    in_v1: InputPathType,
    prefix: str,
    mask: InputPathType | None = None,
    fa_thr: float | None = None,
    fa_sca: float | None = None,
    workdir: str | None = None,
    no_clean: bool = False,
    qc_prefix: str | None = None,
    no_cmd_out: bool = False,
    no_qc_view: bool = False,
    runner: Runner | None = None,
) -> FatProcDecmapOutputs:
    """
    This program makes a directionally encoded color (DEC) map for DTI results.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        in_fa: Input FA (scalar) map.
        in_v1: Input first eigenvector (3-vector) map.
        prefix: Set prefix (and path) for output DWI data.
        mask: Optional mask for picking out a region. Otherwise, only places\
            with FA>0 are given coloration.
        fa_thr: For QC1 type of DEC images, use FFF to threshold where DEC\
            values are calculated (default: 0.2).
        fa_sca: For QC2 type of DEC images, use SSS to scale the FA weighting\
            of what would otherwise be a 'classical' DEC map (default: 0.7).
        workdir: Specify a working directory, which can be removed (default:\
            '__WORKING_decmap').
        no_clean: Do not delete temporary files when finishing.
        qc_prefix: Set the prefix of the QC image files (default: 'PREFIX').
        no_cmd_out: Do not save the command line call of this program and\
            location where it was run.
        no_qc_view: Turn off generating QC image files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatProcDecmapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_PROC_DECMAP_METADATA)
    cargs = []
    cargs.append("fat_proc_decmap")
    cargs.extend([
        "-in_fa",
        execution.input_file(in_fa)
    ])
    cargs.extend([
        "-in_v1",
        execution.input_file(in_v1)
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if fa_thr is not None:
        cargs.extend([
            "-fa_thr",
            str(fa_thr)
        ])
    if fa_sca is not None:
        cargs.extend([
            "-fa_sca",
            str(fa_sca)
        ])
    if workdir is not None:
        cargs.extend([
            "-workdir",
            workdir
        ])
    if no_clean:
        cargs.append("-no_clean")
    if qc_prefix is not None:
        cargs.extend([
            "-qc_prefix",
            qc_prefix
        ])
    if no_cmd_out:
        cargs.append("-no_cmd_out")
    if no_qc_view:
        cargs.append("-no_qc_view")
    ret = FatProcDecmapOutputs(
        root=execution.output_file("."),
        outfile_dec_rgb=execution.output_file(prefix + "_dec.nii.gz"),
        outfile_dec_unwt_thr=execution.output_file(prefix + "_dec_unwt_thr.nii.gz"),
        outfile_dec_sca=execution.output_file(prefix + "_dec_sca*.nii.gz"),
        qc_dec_images=execution.output_file(prefix + "_qc_dec*.png"),
        qc_dec_unwt_thrx_images=execution.output_file(prefix + "_qc_dec_unwt_thrx*.png"),
        qc_dec_sca_images=execution.output_file(prefix + "_qc_dec_sca*.png"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_PROC_DECMAP_METADATA",
    "FatProcDecmapOutputs",
    "fat_proc_decmap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_ADD_NEW_TP_METADATA = Metadata(
    id="c092850ac196635799818218f41e6c048de46b98.boutiques",
    name="mri_add_new_tp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriAddNewTpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_add_new_tp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_add_new_tp(
    base_id: str,
    newtp_id: str,
    runner: Runner | None = None,
) -> MriAddNewTpOutputs:
    """
    Adds a new time point to the base/template without re-creating the base. Only
    the new time point needs to be run longitudinally.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        base_id: The ID of the base template.
        newtp_id: The ID of the new time point to be added.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriAddNewTpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_ADD_NEW_TP_METADATA)
    cargs = []
    cargs.append("mri_add_new_tp")
    cargs.append(base_id)
    cargs.append(newtp_id)
    ret = MriAddNewTpOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_ADD_NEW_TP_METADATA",
    "MriAddNewTpOutputs",
    "mri_add_new_tp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF2SURF_METADATA = Metadata(
    id="d3f6f520e28b08a22c957c86939490db1fe6b107.boutiques",
    name="surf2surf",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class Surf2surfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf2surf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surf2surf(
    input_surface: InputPathType,
    output_surface: InputPathType,
    input_convention: str | None = None,
    output_convention: str | None = None,
    input_ref_volume: InputPathType | None = None,
    output_ref_volume: InputPathType | None = None,
    transform: InputPathType | None = None,
    output_type: str | None = None,
    output_values: str | None = None,
    runner: Runner | None = None,
) -> Surf2surfOutputs:
    """
    Conversions between surface formats and/or conventions.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_surface: Input surface.
        output_surface: Output surface.
        input_convention: Input convention [default=caret] - only used if\
            output convention is different.
        output_convention: Output convention [default=same as input].
        input_ref_volume: Input reference volume - Must set this if changing\
            conventions.
        output_ref_volume: Output reference volume [default=same as input].
        transform: In-to-out ASCII matrix or out-to-in warpfield\
            [default=identity].
        output_type: Output type: ASCII, VTK, GIFTI_ASCII, GIFTI_BIN,\
            GIFTI_BIN_GZ (default).
        output_values: Set output scalar values (e.g.\
            --values=mysurface.func.gii or --values=1).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Surf2surfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF2SURF_METADATA)
    cargs = []
    cargs.append("surf2surf")
    cargs.append("-i")
    cargs.extend([
        "--surfin",
        execution.input_file(input_surface)
    ])
    cargs.append("-o")
    cargs.extend([
        "--surfout",
        execution.input_file(output_surface)
    ])
    if input_convention is not None:
        cargs.extend([
            "--convin",
            input_convention
        ])
    if output_convention is not None:
        cargs.extend([
            "--convout",
            output_convention
        ])
    if input_ref_volume is not None:
        cargs.extend([
            "--volin",
            execution.input_file(input_ref_volume)
        ])
    if output_ref_volume is not None:
        cargs.extend([
            "--volout",
            execution.input_file(output_ref_volume)
        ])
    if transform is not None:
        cargs.extend([
            "--xfm",
            execution.input_file(transform)
        ])
    if output_type is not None:
        cargs.extend([
            "--outputtype",
            output_type
        ])
    if output_values is not None:
        cargs.extend([
            "--values",
            output_values
        ])
    ret = Surf2surfOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF2SURF_METADATA",
    "Surf2surfOutputs",
    "surf2surf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

T4IMGS_4DFP_METADATA = Metadata(
    id="ff1e1b6a51149ecedfe8127fd7944168fd2882ae.boutiques",
    name="t4imgs_4dfp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class T4imgs4dfpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `t4imgs_4dfp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    transformed_image: OutputPathType
    """Transformed 4dfp image as output."""


def t4imgs_4dfp(
    input_images: list[InputPathType],
    output_image: str,
    sqrt_normalize: bool = False,
    cubic_spline: bool = False,
    output_nan: bool = False,
    convert_t4: bool = False,
    nearest_neighbor: bool = False,
    output_111_space: bool = False,
    output_222_space: bool = False,
    output_333n_space: str | None = None,
    duplicate_dimensions: str | None = None,
    big_endian: bool = False,
    little_endian: bool = False,
    runner: Runner | None = None,
) -> T4imgs4dfpOutputs:
    """
    Freesurfer tool for transforming images according to a specified T4 file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_images: Input list of 4dfp images.
        output_image: Output file name for the transformed image.
        sqrt_normalize: Normalize by sqrt(n) rather than n (for z images).
        cubic_spline: Interpolate by 3D cubic spline (default is 3D linear).
        output_nan: Output NaN (default 0.0) for undefined values.
        convert_t4: Internally convert to_711-2A_t4->to_711-2B_t4.
        nearest_neighbor: Use nearest neighbor interpolation.
        output_111_space: Output in 111 space instead of default 333.0 space.
        output_222_space: Output in 222 space instead of default 333.0 space.
        output_333n_space: Output in 333.n space (y shifted up by n pixels).
        duplicate_dimensions: Duplicate dimensions of specified image.
        big_endian: Output in big endian format.
        little_endian: Output in little endian format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `T4imgs4dfpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(T4IMGS_4DFP_METADATA)
    cargs = []
    cargs.append("t4imgs_4dfp")
    if sqrt_normalize:
        cargs.append("-z")
    if cubic_spline:
        cargs.append("-s")
    if output_nan:
        cargs.append("-N")
    if convert_t4:
        cargs.append("-B")
    if nearest_neighbor:
        cargs.append("-n")
    if output_111_space:
        cargs.append("-O111")
    if output_222_space:
        cargs.append("-O222")
    if output_333n_space is not None:
        cargs.extend([
            "-O333.n",
            output_333n_space
        ])
    if duplicate_dimensions is not None:
        cargs.extend([
            "-O",
            duplicate_dimensions
        ])
    if big_endian:
        cargs.append("-@b")
    if little_endian:
        cargs.append("-@l")
    cargs.extend([execution.input_file(f) for f in input_images])
    cargs.append(output_image)
    ret = T4imgs4dfpOutputs(
        root=execution.output_file("."),
        transformed_image=execution.output_file(output_image + ".4dfp.img"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "T4IMGS_4DFP_METADATA",
    "T4imgs4dfpOutputs",
    "t4imgs_4dfp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MORPHOLOGY_METADATA = Metadata(
    id="f01b6fc71ec054526271073daced052e1a34a01b.boutiques",
    name="mri_morphology",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMorphologyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_morphology(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """The result of the morphological operation applied to the input volume."""


def mri_morphology(
    input_volume: InputPathType,
    operation: typing.Literal["open", "close", "dilate", "erode", "mode", "fill_holes", "erode_bottom", "dilate_thresh", "erode_thresh"],
    number_iter: int,
    output_volume: InputPathType,
    label_option: float | None = None,
    runner: Runner | None = None,
) -> MriMorphologyOutputs:
    """
    MRI Morphology Tool - performs various morphological operations on a volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume file on which operations are to be applied.
        operation: Morphological operation to be performed. Options include:\
            open, close, dilate, erode, mode, fill_holes, erode_bottom,\
            dilate_thresh, erode_thresh.
        number_iter: Number of iterations to apply the operation.
        output_volume: Output volume file to store the results of the\
            operation.
        label_option: Only apply operations to the specified label instead of\
            all nonzero voxels.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMorphologyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MORPHOLOGY_METADATA)
    cargs = []
    cargs.append("mri_morphology")
    cargs.append(execution.input_file(input_volume))
    cargs.append(operation)
    cargs.append(str(number_iter))
    cargs.append(execution.input_file(output_volume))
    if label_option is not None:
        cargs.extend([
            "-l",
            str(label_option)
        ])
    ret = MriMorphologyOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(output_volume).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MORPHOLOGY_METADATA",
    "MriMorphologyOutputs",
    "mri_morphology",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GRAD_UNWARP_METADATA = Metadata(
    id="3f8f59f71178da3b91ee74fc055a9520bba22b05.boutiques",
    name="grad_unwarp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class GradUnwarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `grad_unwarp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    mgh_output: OutputPathType
    """Output file in MGH format"""
    cor_output: OutputPathType
    """Output directory in COR format"""


def grad_unwarp(
    infile: InputPathType,
    outfile: str,
    seriesno: str | None = None,
    unwarp_type: str | None = None,
    nojac: bool = False,
    corfov: bool = False,
    cor: bool = False,
    interp: str | None = None,
    matlab_binary: str | None = "/space/lyon/6/pubsw/common/matlab/6.5/bin/matlab",
    runner: Runner | None = None,
) -> GradUnwarpOutputs:
    """
    Convert, dewarp, and resample DICOM files to MGH files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        infile: Input file or directory (dcmfile, dcmdir, or mghfile).
        outfile: Output file in MGH format.
        seriesno: DICOM series number, required if input is a directory.
        unwarp_type: Gradient unwarping displacement type or map file (required\
            for MGH file).
        nojac: Do not perform jacobian correction when unwarping.
        corfov: Resample to Coronal FOV.
        cor: Output in COR format instead of MGH.
        interp: Interpolation method (cubic, linear, nearest, spline).
        matlab_binary: Path to the Matlab binary, version 6.5 or higher\
            required.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GradUnwarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GRAD_UNWARP_METADATA)
    cargs = []
    cargs.append("grad_unwarp")
    cargs.append(execution.input_file(infile))
    if seriesno is not None:
        cargs.extend([
            "-s",
            seriesno
        ])
    if unwarp_type is not None:
        cargs.extend([
            "-unwarp",
            unwarp_type
        ])
    if nojac:
        cargs.append("-nojac")
    if corfov:
        cargs.append("-corfov")
    if cor:
        cargs.append("-cor")
    if interp is not None:
        cargs.extend([
            "-interp",
            interp
        ])
    cargs.extend([
        "-o",
        outfile
    ])
    if matlab_binary is not None:
        cargs.extend([
            "-matlab",
            matlab_binary
        ])
    ret = GradUnwarpOutputs(
        root=execution.output_file("."),
        mgh_output=execution.output_file(outfile),
        cor_output=execution.output_file(outfile + "/"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GRAD_UNWARP_METADATA",
    "GradUnwarpOutputs",
    "grad_unwarp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_CC_METADATA = Metadata(
    id="15e13320aa7ce00fbf8db493c28c6884f3b1ec76.boutiques",
    name="mri_cc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriCcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_cc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType | None
    """Output volume including CC segmentation results."""


def mri_cc(
    subject_name: str,
    output_file: str | None = None,
    aseg_file: InputPathType | None = None,
    norm_file: InputPathType | None = None,
    sdir: str | None = None,
    rotation_lta: InputPathType | None = None,
    force_flag: bool = False,
    include_fornix: bool = False,
    compartments: float | None = None,
    thickness: float | None = None,
    skip_voxels: float | None = None,
    max_rotation: float | None = 7.0,
    runner: Runner | None = None,
) -> MriCcOutputs:
    """
    Segments the corpus callosum into five separate labels in the subcortical
    segmentation volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Subject name used in processing.
        output_file: Write aseg including CC to SDIR/mri/<fname>.
        aseg_file: Read aseg from SDIR/mri/<fname>.
        norm_file: Read norm from SDIR/mri/<fname>.
        sdir: Set SUBJECTS_DIR to <dname>.
        rotation_lta: Write rotation lta to global <fname>.
        force_flag: Process regardless of existing CC in input.
        include_fornix: Include fornix in segmentation.
        compartments: Subdivide into <int> compartments.
        thickness: Setting CC thickness to <int> mm.
        skip_voxels: Skipping <int> voxels in rotational align.
        max_rotation: Set max of rotations to be searched (default=7deg).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriCcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_CC_METADATA)
    cargs = []
    cargs.append("mri_cc")
    cargs.append(subject_name)
    if output_file is not None:
        cargs.extend([
            "-o",
            output_file
        ])
    if aseg_file is not None:
        cargs.extend([
            "-aseg",
            execution.input_file(aseg_file)
        ])
    if norm_file is not None:
        cargs.extend([
            "-norm",
            execution.input_file(norm_file)
        ])
    if sdir is not None:
        cargs.extend([
            "-sdir",
            sdir
        ])
    if rotation_lta is not None:
        cargs.extend([
            "-lta",
            execution.input_file(rotation_lta)
        ])
    if force_flag:
        cargs.append("-force")
    if include_fornix:
        cargs.append("-f")
    if compartments is not None:
        cargs.extend([
            "-d",
            str(compartments)
        ])
    if thickness is not None:
        cargs.extend([
            "-t",
            str(thickness)
        ])
    if skip_voxels is not None:
        cargs.extend([
            "-s",
            str(skip_voxels)
        ])
    if max_rotation is not None:
        cargs.extend([
            "-m",
            str(max_rotation)
        ])
    ret = MriCcOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file("SDIR/mri/" + output_file) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_CC_METADATA",
    "MriCcOutputs",
    "mri_cc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOXEL2MESH_METADATA = Metadata(
    id="61319a325faead4ced930defcbdd82b99a6a72af.boutiques",
    name="voxel2mesh",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class Voxel2meshConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Voxel2meshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `voxel2mesh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output mesh file."""


def voxel2mesh(
    input_: InputPathType,
    output: str,
    blocky: bool = False,
    threshold: float | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Voxel2meshConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Voxel2meshOutputs:
    """
    Generate a surface mesh representation from a voxel image.
    
    This command utilises the Marching Cubes algorithm to generate a polygonal
    surface that represents the isocontour(s) of the input image at a particular
    intensity. By default, an appropriate threshold will be determined
    automatically from the input image, however the intensity value of the
    isocontour(s) can instead be set manually using the -threhsold option.
    
    If the -blocky option is used, then the Marching Cubes algorithm will not be
    used. Instead, the input image will be interpreted as a binary mask image,
    and polygonal surfaces will be generated at the outer faces of the voxel
    clusters within the mask.
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        input_: the input image.
        output: the output mesh file.
        blocky: generate a 'blocky' mesh that precisely represents the voxel\
            edges.
        threshold: manually set the intensity threshold for the Marching Cubes\
            algorithm.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Voxel2meshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOXEL2MESH_METADATA)
    cargs = []
    cargs.append("voxel2mesh")
    if blocky:
        cargs.append("-blocky")
    if threshold is not None:
        cargs.extend([
            "-threshold",
            str(threshold)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(input_))
    cargs.append(output)
    ret = Voxel2meshOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOXEL2MESH_METADATA",
    "Voxel2meshConfig",
    "Voxel2meshOutputs",
    "voxel2mesh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SUMA_RENUMBER_FS_METADATA = Metadata(
    id="c19b88d98568eb300b3deddf6a92cffe231ec7b8.boutiques",
    name="@SUMA_renumber_FS",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSumaRenumberFsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__suma_renumber_fs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    ren_all: OutputPathType
    """Whole parcellation/segmentation file with renumbered ROIs."""
    ren_gm: OutputPathType
    """Gray matter tissue segmentation map."""
    ren_wmat: OutputPathType
    """White matter tissue segmentation map."""
    ren_csf: OutputPathType
    """Cerebrospinal fluid tissue segmentation map."""
    ren_vent: OutputPathType
    """Ventricles and choroid plexus tissue segmentation map."""
    ren_othr: OutputPathType
    """Other tissue segmentation map (optic chiasm, non-WM-hypointens, etc.)."""
    ren_unkn: OutputPathType
    """Unknown tissue segmentation map (FS-defined 'unknown', with voxel value
    >0)."""
    ren_gmrois: OutputPathType
    """Gray matter ROIs without '*-Cerebral-Cortex' dots."""
    fs_ap_wm: OutputPathType
    """White matter mask (excluding the dotted part from FS)."""
    fs_ap_latvent: OutputPathType
    """Lateral ventricles mask ('*-Lateral-Ventricle')."""
    ren_lbl_table: OutputPathType
    """Labeltable of the new ROI values."""


def v__suma_renumber_fs(
    sumadir: str,
    runner: Runner | None = None,
) -> VSumaRenumberFsOutputs:
    """
    This script processes FreeSurfer-generated parcellation files and produces
    various derived datasets and segmentation maps.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        sumadir: Path to the 'SUMA/' directory created by @SUMA_Make_Spec_FS.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSumaRenumberFsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SUMA_RENUMBER_FS_METADATA)
    cargs = []
    cargs.append("@SUMA_renumber_FS")
    cargs.append(sumadir)
    ret = VSumaRenumberFsOutputs(
        root=execution.output_file("."),
        ren_all=execution.output_file("*_REN_all.nii.gz"),
        ren_gm=execution.output_file("*_REN_gm.nii.gz"),
        ren_wmat=execution.output_file("*_REN_wmat.nii.gz"),
        ren_csf=execution.output_file("*_REN_csf.nii.gz"),
        ren_vent=execution.output_file("*_REN_vent.nii.gz"),
        ren_othr=execution.output_file("*_REN_othr.nii.gz"),
        ren_unkn=execution.output_file("*_REN_unkn.nii.gz"),
        ren_gmrois=execution.output_file("*_REN_gmrois.nii.gz"),
        fs_ap_wm=execution.output_file("fs_ap_wm.nii.gz"),
        fs_ap_latvent=execution.output_file("fs_ap_latvent.nii.gz"),
        ren_lbl_table=execution.output_file("*_REN_all.niml.lt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSumaRenumberFsOutputs",
    "V__SUMA_RENUMBER_FS_METADATA",
    "v__suma_renumber_fs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_COPY_VALUES_METADATA = Metadata(
    id="cc7c40825cfb55a4e617070c14c0897527683ac8.boutiques",
    name="mri_copy_values",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriCopyValuesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_copy_values(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output volume with copied values from source."""


def mri_copy_values(
    source_volume: InputPathType,
    target_volume: InputPathType,
    output_volume: str,
    runner: Runner | None = None,
) -> MriCopyValuesOutputs:
    """
    No description.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        source_volume: Source volume from which values are copied.
        target_volume: Target volume to which values are copied.
        output_volume: Output volume where the result will be stored.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriCopyValuesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_COPY_VALUES_METADATA)
    cargs = []
    cargs.append("mri_copy_values")
    cargs.append(execution.input_file(source_volume))
    cargs.append(execution.input_file(target_volume))
    cargs.append(output_volume)
    ret = MriCopyValuesOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_COPY_VALUES_METADATA",
    "MriCopyValuesOutputs",
    "mri_copy_values",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_CONVERT_METADATA = Metadata(
    id="072cf5d2422186514e5e2726e7afe06ff330f744.boutiques",
    name="mri_convert",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriConvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_convert(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    converted_volume: OutputPathType
    """Converted volume output file"""


def mri_convert(
    inp_volume: InputPathType,
    out_volume: str,
    runner: Runner | None = None,
) -> MriConvertOutputs:
    """
    A general purpose utility for converting between different file formats
    supported by FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        inp_volume: The input volume file.
        out_volume: The output volume file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriConvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_CONVERT_METADATA)
    cargs = []
    cargs.append("mri_convert")
    cargs.append(execution.input_file(inp_volume))
    cargs.append(out_volume)
    cargs.append("[OPTIONS]")
    ret = MriConvertOutputs(
        root=execution.output_file("."),
        converted_volume=execution.output_file(out_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_CONVERT_METADATA",
    "MriConvertOutputs",
    "mri_convert",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SPLINE3_TEST_METADATA = Metadata(
    id="329f87f17c7d7e02a8b2c078f5a794aee33adae2.boutiques",
    name="Spline3_test",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Spline3TestOutputs(typing.NamedTuple):
    """
    Output object returned when calling `spline3_test(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_ynew: OutputPathType
    """Interpolated y values at new x positions."""
    output_ynewarr: OutputPathType
    """Array format of interpolated y values at new x positions."""


def spline3_test(
    x_values: list[float],
    y_values: list[float],
    x_new_values: list[float],
    runner: Runner | None = None,
) -> Spline3TestOutputs:
    """
    A tool for cubic spline interpolation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        x_values: Original x values for interpolation.
        y_values: Original y values corresponding to x values.
        x_new_values: New x values where interpolation is evaluated.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Spline3TestOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPLINE3_TEST_METADATA)
    cargs = []
    cargs.append("Spline3_test")
    cargs.extend(map(str, x_values))
    cargs.extend(map(str, y_values))
    cargs.extend(map(str, x_new_values))
    ret = Spline3TestOutputs(
        root=execution.output_file("."),
        output_ynew=execution.output_file("Ynew.txt"),
        output_ynewarr=execution.output_file("Ynewarr.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SPLINE3_TEST_METADATA",
    "Spline3TestOutputs",
    "spline3_test",
]
